@@ -92,10 +92,11 @@ struct option long_opts[] = {
   {"color-scheme"         , required_argument , 0 , 0  }  ,
   {"crawlers-only"        , no_argument       , 0 , 0  }  ,
   {"daemonize"            , no_argument       , 0 , 0  }  ,
-  {"datetime-format"     , required_argument , 0 , 0  }  ,
+  {"datetime-format"      , required_argument , 0 , 0  }  ,
   {"date-format"          , required_argument , 0 , 0  }  ,
   {"date-spec"            , required_argument , 0 , 0  }  ,
   {"db-path"              , required_argument , 0 , 0  }  ,
+  {"fname-as-vhost"       , required_argument , 0 , 0  }  ,
   {"dcf"                  , no_argument       , 0 , 0  }  ,
   {"double-decode"        , no_argument       , 0 , 0  }  ,
   {"enable-panel"         , required_argument , 0 , 0  }  ,
@@ -168,117 +169,158 @@ cmd_help (void)
 
   printf (
   /* Log & Date Format Options */
-  CYN "LOG & DATE FORMAT OPTIONS\n\n" RESET
-  "  --log-format=<logformat>        - Specify log format. Inner quotes need escaping, or use single quotes.\n"
+  CYN "LOG & DATE FORMAT OPTIONS" RESET
+  "\n\n"
+  "  --log-format=<logformat>        - Specify log format. Inner quotes need\n"
+  "                                    escaping, or use single quotes.\n"
   "  --date-format=<dateformat>      - Specify log date format. e.g., %%d/%%b/%%Y\n"
   "  --time-format=<timeformat>      - Specify log time format. e.g., %%H:%%M:%%S\n"
-  "  --datetime-format=<dt-format>   - Specify log date and time format. e.g., %%d/%%b/%%Y %%H:%%M:%%S %%z\n"
+  "  --datetime-format=<dt-format>   - Specify log date and time format. e.g.,\n"
+  "                                    %%d/%%b/%%Y %%H:%%M:%%S %%z\n"
   "\n"
   /* User Interface Options */
-  CYN "USER INTERFACE OPTIONS\n\n" RESET
+  CYN "USER INTERFACE OPTIONS" RESET
+  "\n\n"
   "  -c --config-dialog              - Prompt log/date/time configuration window.\n"
   "  -i --hl-header                  - Color highlight active panel.\n"
   "  -m --with-mouse                 - Enable mouse support on main dashboard.\n"
-  "  --color=<fg:bg[attrs, PANEL]>   - Specify custom colors. See manpage for more details.\n"
-  "  --color-scheme=<1|2|3>          - Schemes: 1 => Grey, 2 => Green, 3 => Monokai.\n"
-  "  --html-custom-css=<path.css>    - Specify a custom CSS file in the HTML report.\n"
-  "  --html-custom-js=<path.js>      - Specify a custom JS file in the HTML report.\n"
+  "  --color=<fg:bg[attrs, PANEL]>   - Specify custom colors. See manpage for more\n"
+  "                                    details.\n"
+  "  --color-scheme=<1|2|3>          - Schemes: 1 => Grey, 2 => Green, 3 =>\n"
+  "                                    Monokai.\n"
+  "  --html-custom-css=<path.css>    - Specify a custom CSS file in the HTML\n"
+  "                                    report.\n"
+  "  --html-custom-js=<path.js>      - Specify a custom JS file in the HTML\n"
+  "                                    report.\n"
   "  --html-prefs=<json_obj>         - Set default HTML report preferences.\n"
   "  --html-report-title=<title>     - Set HTML report page title and header.\n"
-  "  --html-refresh=<secs>           - Refresh HTML report every X seconds (>=1 or <=60).\n"
+  "  --html-refresh=<secs>           - Refresh HTML report every X seconds (>=1 or\n"
+  "                                    <=60).\n"
   "  --json-pretty-print             - Format JSON output w/ tabs & newlines.\n"
-  "  --max-items                     - Maximum number of items to show per panel. See man page for limits.\n"
+  "  --max-items                     - Maximum number of items to show per panel.\n"
+  "                                    See man page for limits.\n"
   "  --no-color                      - Disable colored output.\n"
   "  --no-column-names               - Don't write column names in term output.\n"
   "  --no-csv-summary                - Disable summary metrics on the CSV output.\n"
   "  --no-html-last-updated          - Hide HTML last updated field.\n"
-  "  --no-parsing-spinner            - Disable progress metrics and parsing spinner.\n"
+  "  --no-parsing-spinner            - Disable progress metrics and parsing\n"
+  "                                    spinner.\n"
   "  --no-progress                   - Disable progress metrics.\n"
   "  --no-tab-scroll                 - Disable scrolling through panels on TAB.\n"
-  "  --tz=<timezone>                 - Use the specified timezone (canonical name, e.g., America/Chicago).\n"
+  "  --tz=<timezone>                 - Use the specified timezone (canonical name,\n"
+  "                                    e.g., America/Chicago).\n"
   "\n"
   ""
   /* Server Options */
-  CYN "SERVER OPTIONS\n\n" RESET
+  CYN "SERVER OPTIONS" RESET
+  "\n\n"
   "  --addr=<addr>                   - Specify IP address to bind server to.\n"
-  "  --unix-socket=<addr>            - Specify UNIX-domain socket address to bind server to.\n"
-  "  --daemonize                     - Run as daemon (if --real-time-html enabled).\n"
+  "  --unix-socket=<addr>            - Specify UNIX-domain socket address to bind\n"
+  "                                    server to.\n"
+  "  --daemonize                     - Run as daemon (if --real-time-html\n"
+  "                                    enabled).\n"
   "  --fifo-in=<path>                - Path to read named pipe (FIFO).\n"
   "  --fifo-out=<path>               - Path to write named pipe (FIFO).\n"
-  "  --origin=<addr>                 - Ensure clients send this origin header upon the WebSocket handshake.\n"
-  "  --pid-file=<path>               - Write PID to a file when --daemonize is used.\n"
+  "  --origin=<addr>                 - Ensure clients send this origin header upon\n"
+  "                                    the WebSocket handshake.\n"
+  "  --pid-file=<path>               - Write PID to a file when --daemonize is\n"
+  "                                    used.\n"
   "  --port=<port>                   - Specify the port to use.\n"
   "  --real-time-html                - Enable real-time HTML output.\n"
   "  --ssl-cert=<cert.crt>           - Path to TLS/SSL certificate.\n"
   "  --ssl-key=<priv.key>            - Path to TLS/SSL private key.\n"
   "  --user-name=<username>          - Run as the specified user.\n"
   "  --ws-url=<url>                  - URL to which the WebSocket server responds.\n"
-  "  --ping-interval=<secs>          - Enable WebSocket ping with specified interval in seconds.\n"
+  "  --ping-interval=<secs>          - Enable WebSocket ping with specified\n"
+  "                                    interval in seconds.\n"
   "\n"
   ""
   /* File Options */
-  CYN "FILE OPTIONS\n\n" RESET
+  CYN "FILE OPTIONS" RESET
+  "\n\n"
   "  -                               - The log file to parse is read from stdin.\n"
   "  -f --log-file=<filename>        - Path to input log file.\n"
-  "  -l --debug-file=<filename>      - Send all debug messages to the specified file.\n"
+  "  -l --debug-file=<filename>      - Send all debug messages to the specified\n"
+  "                                    file.\n"
   "  -p --config-file=<filename>     - Custom configuration file.\n"
-  "  -S --log-size=<number>          - Specify the log size, useful when piping in logs.\n"
+  "  -S --log-size=<number>          - Specify the log size, useful when piping in\n"
+  "                                    logs.\n"
   "  --invalid-requests=<filename>   - Log invalid requests to the specified file.\n"
   "  --no-global-config              - Don't load global configuration file.\n"
-  "  --unknowns-log=<filename>       - Log unknown browsers and OSs to the specified file.\n"
+  "  --unknowns-log=<filename>       - Log unknown browsers and OSs to the\n"
+  "                                    specified file.\n"
   "\n"
   ""
   /* Parse Options */
-  CYN "PARSE OPTIONS\n\n" RESET
+  CYN "PARSE OPTIONS" RESET
+  "\n\n"
   "  -a --agent-list                 - Enable a list of user-agents by host.\n"
   "  -b --browsers-file=<path>       - Use additional custom list of browsers.\n"
   "  -d --with-output-resolver       - Enable IP resolver on HTML|JSON output.\n"
-  "  -e --exclude-ip=<IP>            - Exclude one or multiple IPv4/6. Allows IP ranges\n"
-  "                                    e.g. 192.168.0.1-192.168.0.10\n"
+  "  -e --exclude-ip=<IP>            - Exclude one or multiple IPv4/6. Allows IP\n"
+  "                                    ranges. e.g., 192.168.0.1-192.168.0.10\n"
   "  -H --http-protocol=<yes|no>     - Set/unset HTTP request protocol if found.\n"
   "  -M --http-method=<yes|no>       - Set/unset HTTP request method if found.\n"
   "  -o --output=file.html|json|csv  - Output either an HTML, JSON or a CSV file.\n"
-  "  -q --no-query-string            - Strip request's query string. This can decrease memory consumption.\n"
+  "  -q --no-query-string            - Strip request's query string. This can\n"
+  "                                    decrease memory consumption.\n"
   "  -r --no-term-resolver           - Disable IP resolver on terminal output.\n"
   "  --444-as-404                    - Treat non-standard status code 444 as 404.\n"
-  "  --4xx-to-unique-count           - Add 4xx client errors to the unique visitors count.\n"
+  "  --4xx-to-unique-count           - Add 4xx client errors to the unique\n"
+  "                                    visitors count.\n"
   "  --all-static-files              - Include static files with a query string.\n"
-  "  --anonymize-ip                  - Anonymize IP addresses before outputting to report.\n"
-  "  --anonymize-level=<1|2|3>       - Anonymization levels: 1 => default, 2 => strong, 3 => pedantic.\n"
+  "  --anonymize-ip                  - Anonymize IP addresses before outputting to\n"
+  "                                    report.\n"
+  "  --anonymize-level=<1|2|3>       - Anonymization levels: 1 => default, 2 =>\n"
+  "                                    strong, 3 => pedantic.\n"
   "  --crawlers-only                 - Parse and display only crawlers.\n"
-  "  --date-spec=<date|hr|min>       - Date specificity. Possible values: `date` (default), `hr` or `min`.\n"
+  "  --date-spec=<date|hr|min>       - Date specificity. Possible values: `date`\n"
+  "                                    (default), `hr` or `min`.\n"
+  "  --db-path=<path>                - Persist data to disk on exit to the given\n"
+  "                                    path or /tmp as default.\n"
   "  --double-decode                 - Decode double-encoded values.\n"
   "  --enable-panel=<PANEL>          - Enable parsing/displaying the given panel.\n"
-  "  --hide-referrer=<NEEDLE>        - Hide a referrer but still count it. Wild cards are allowed.\n"
-  "                                    i.e., *.bing.com\n"
-  "  --hour-spec=<hr|min>            - Hour specificity. Possible values: `hr` (default),\n"
-  "                                    or `min` (tenth of a min).\n"
+  "  --fname-as-vhost=<regex>        - Use log filename(s) as virtual host(s).\n"
+  "                                    POSIX regex is passed to extract virtual\n"
+  "                                    host.\n"
+  "  --hide-referrer=<NEEDLE>        - Hide a referrer but still count it. Wild\n"
+  "                                    cards are allowed. i.e., *.bing.com\n"
+  "  --hour-spec=<hr|min>            - Hour specificity. Possible values: `hr`\n"
+  "                                    (default) or `min` (tenth of a min).\n"
   "  --ignore-crawlers               - Ignore crawlers.\n"
   "  --ignore-panel=<PANEL>          - Ignore parsing/displaying the given panel.\n"
-  "  --ignore-referrer=<NEEDLE>      - Ignore a referrer from being counted. Wild cards are allowed.\n"
-  "                                    i.e., *.bing.com\n"
+  "  --ignore-referrer=<NEEDLE>      - Ignore a referrer from being counted. Wild\n"
+  "                                    cards are allowed. i.e., *.bing.com\n"
   "  --ignore-statics=<req|panel>    - Ignore static requests.\n"
   "                                    req => Ignore from valid requests.\n"
-  "                                    panel => Ignore from valid requests and panels.\n"
+  "                                    panel => Ignore from valid requests and\n"
+  "                                    panels.\n"
   "  --ignore-status=<CODE>          - Ignore parsing the given status code.\n"
   "  --keep-last=<NDAYS>             - Keep the last NDAYS in storage.\n"
   "  --no-ip-validation              - Disable client IPv4/6  validation.\n"
   "  --no-strict-status              - Disable HTTP status code validation.\n"
   "  --num-tests=<number>            - Number of lines to test. >= 0 (10 default)\n"
-  "  --persist                       - Persist data to disk on exit to the given --db-path or to /tmp.\n"
+  "  --persist                       - Persist data to disk on exit to the given\n"
+  "                                    --db-path or to /tmp.\n"
   "  --process-and-exit              - Parse log and exit without outputting data.\n"
-  "  --real-os                       - Display real OS names. e.g, Windows XP, Snow Leopard.\n"
-  "  --restore                       - Restore data from disk from the given --db-path or from /tmp.\n"
-  "  --sort-panel=PANEL,METRIC,ORDER - Sort panel on initial load. e.g., --sort-panel=VISITORS,BY_HITS,ASC.\n"
+  "  --real-os                       - Display real OS names. e.g, Windows XP,\n"
+  "                                    Snow Leopard.\n"
+  "  --restore                       - Restore data from disk from the given\n"
+  "                                    --db-path or from /tmp.\n"
+  "  --sort-panel=PANEL,METRIC,ORDER - Sort panel on initial load. e.g.,\n"
+  "                                    --sort-panel=VISITORS,BY_HITS,ASC.\n"
   "                                    See manpage for a list of panels/fields.\n"
-  "  --static-file=<extension>       - Add static file extension. e.g.: .mp3. Extensions are case sensitive.\n"
+  "  --static-file=<extension>       - Add static file extension. e.g.: .mp3.\n"
+  "                                    Extensions are case sensitive.\n"
   "\n"
 
 /* GeoIP Options */
 #ifdef HAVE_GEOLOCATION
-  CYN "GEOIP OPTIONS\n\n" RESET
+  CYN "GEOIP OPTIONS" RESET
+  "\n\n"
 #ifdef HAVE_LIBGEOIP
-  "  -g --std-geoip                  - Standard GeoIP database for less memory consumption.\n"
+  "  -g --std-geoip                  - Standard GeoIP database for less memory\n"
+  "                                    consumption (legacy DB).\n"
 #endif
   "  --geoip-database=<path>         - Specify path to GeoIP database file.\n"
   "                                    i.e., GeoLiteCity.dat, GeoIPv6.dat ...\n"
@@ -286,11 +328,13 @@ cmd_help (void)
 #endif
 
 /* Other Options */
-  CYN "OTHER OPTIONS\n\n" RESET
+  CYN "OTHER OPTIONS" RESET
+  "\n\n"
   "  -h --help                       - This help.\n"
   "  -s --storage                    - Display current storage method. e.g., Hash.\n"
   "  -V --version                    - Display version information and exit.\n"
-  "  --dcf                           - Display the path of the default config file when `-p` is not used.\n"
+  "  --dcf                           - Display the path of the default config file\n"
+  "                                    when `-p` is not used.\n"
   "\n"
 
   "%s `man goaccess`.\n\n"
@@ -622,6 +666,10 @@ parse_long_opt (const char *name, const char *oarg) {
   if (!strcmp ("db-path", name))
     conf.db_path = oarg;
 
+  /* specifies the regex to extract the virtual host */
+  if (!strcmp ("fname-as-vhost", name) && oarg && *oarg != '\0')
+    conf.fname_as_vhost = oarg;
+
   /* process and exit */
   if (!strcmp ("process-and-exit", name))
     conf.process_and_exit = 1;
