@@ -58,6 +58,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <inttypes.h>
+#include <libgen.h>
 
 #include "gkhash.h"
 
@@ -115,6 +116,8 @@ Logs *
 init_logs (int size) {
   Logs *logs = NULL;
   GLog *glog = NULL;
+  char *fvh = NULL;
+  char const *err;
   int i = 0;
 
   /* if no logs no a pipe nor restoring, nothing to do then */
@@ -134,6 +137,13 @@ init_logs (int size) {
   for (i = 0; i < size; ++i) {
     glog[i].errors = xcalloc (MAX_LOG_ERRORS, sizeof (char *));
     glog[i].filename = xstrdup (conf.filenames[i]);
+    glog[i].fname = xstrdup (basename (glog[i].filename));
+
+    if (!glog->pipe && conf.fname_as_vhost) {
+      if (!(fvh = regex_extract_string (glog[i].fname, conf.fname_as_vhost, 1, &err)))
+        FATAL ("%s %s[%s]", err, glog[i].fname, conf.fname_as_vhost);
+      glog[i].fname_as_vhost = fvh;
+    }
 
     logs->processed = &(glog[i].processed);
     logs->filename = glog[i].filename;
@@ -168,6 +178,8 @@ free_logs (Logs * logs) {
     glog = &logs->glog[i];
 
     free (glog->filename);
+    free (glog->fname);
+    free (glog->fname_as_vhost);
     free_logerrors (glog);
     free (glog->errors);
     if (glog->pipe) {
@@ -1111,6 +1123,8 @@ parse_specifier (GLogItem * logitem, char **str, const char *p, const char *end)
     if (tkn != NULL && *tkn != '\0') {
       /* Make sure the user agent is decoded (i.e.: CloudFront) */
       logitem->agent = decode_url (tkn);
+
+      set_browser_os(logitem);
       set_agent_hash (logitem);
       free (tkn);
       break;
@@ -1792,6 +1806,9 @@ pre_process_log (GLog * glog, char *line, int dry_run) {
   else
     ret = parse_format (logitem, line, fmt);
 
+  if (!glog->piping && conf.fname_as_vhost && glog->fname_as_vhost)
+    logitem->vhost = xstrdup (glog->fname_as_vhost);
+
   if (ret || (ret = verify_missing_fields (logitem))) {
     process_invalid (glog, logitem, line);
     goto cleanup;
